@@ -132,6 +132,11 @@ void edithand_send_initial_packets(struct conn_list *dest)
         send_packet_edit_startpos(pconn, &startpos);
         send_packet_edit_startpos_full(pconn, &startpos_full);
       }
+
+      if (pconn->playing != NULL) {
+        dsend_packet_edit_fogofwar_state(pconn,
+                                         !unfogged_players[player_number(pconn->playing)]);
+      }
     } conn_list_iterate_end;
   } map_startpos_iterate_end;
 }
@@ -356,7 +361,9 @@ void handle_edit_tile_extra(struct connection *pc, int tile,
     return;
   }
 
-  if (eowner != MAP_TILE_OWNER_NULL) {
+  if (eowner != MAP_TILE_OWNER_NULL
+      && (eowner != MAX_UINT8
+          || has_capability("ownernull16", pc->capability))) {
     plr_eowner = player_by_number(eowner);
   } else {
     plr_eowner = NULL;
@@ -388,7 +395,9 @@ void handle_edit_tile(struct connection *pc,
     return;
   }
 
-  if (packet->eowner != MAP_TILE_OWNER_NULL) {
+  if (packet->eowner != MAP_TILE_OWNER_NULL
+      && (packet->eowner != MAX_UINT8
+          || has_capability("ownernull16", pc->capability))) {
     eowner = player_by_number(packet->eowner);
   } else {
     eowner = NULL;
@@ -589,19 +598,14 @@ void handle_edit_unit_remove(struct connection *pc, int owner,
 /************************************************************************//**
   Handle a request to remove a unit given by its id.
 ****************************************************************************/
-void handle_edit_unit_remove_by_id(struct connection *pc, Unit_type_id id16,
-                                   Unit_type_id id32)
+void handle_edit_unit_remove_by_id(struct connection *pc, Unit_type_id id)
 {
   struct unit *punit;
 
-  if (!has_capability("ids32", pc->capability)) {
-    id32 = id16;
-  }
-
-  punit = game_unit_by_number(id32);
-  if (punit == NULL) {
+  punit = game_unit_by_number(id);
+  if (!punit) {
     notify_conn(pc->self, NULL, E_BAD_COMMAND, ftc_editor,
-                _("No such unit (ID %d)."), id32);
+                _("No such unit (ID %d)."), id);
     return;
   }
 
@@ -620,14 +624,9 @@ void handle_edit_unit(struct connection *pc,
   bool changed = FALSE;
   int fuel, hp;
 
-  if (!has_capability("ids32", pc->capability)) {
-    id = packet->id16;
-  } else {
-    id = packet->id32;
-  }
-
+  id = packet->id;
   punit = game_unit_by_number(id);
-  if (punit == NULL) {
+  if (!punit) {
     notify_conn(pc->self, NULL, E_BAD_COMMAND, ftc_editor,
                 _("No such unit (ID %d)."), id);
     return;
@@ -664,7 +663,8 @@ void handle_edit_unit(struct connection *pc,
 
   if (packet->veteran != punit->veteran) {
     int v = packet->veteran;
-    if (!utype_veteran_level(putype, v)) {
+
+    if (utype_veteran_level(putype, v) == NULL) {
       notify_conn(pc->self, NULL, E_BAD_COMMAND, ftc_editor,
                   _("Invalid veteran level %d for unit %d (%s)."),
                   v, id, unit_link(punit));
@@ -759,19 +759,12 @@ void handle_edit_city(struct connection *pc,
   bool changed = FALSE;
   bool need_game_info = FALSE;
   bv_player need_player_info;
-  int cid;
 
-  if (!has_capability("ids32", pc->capability)) {
-    cid = packet->id16;
-  } else {
-    cid = packet->id32;
-  }
-
-  pcity = game_city_by_number(cid);
-  if (pcity == NULL) {
+  pcity = game_city_by_number(packet->id);
+  if (!pcity) {
     notify_conn(pc->self, NULL, E_BAD_COMMAND, ftc_editor,
                 _("Cannot edit city with invalid city ID %d."),
-                cid);
+                packet->id);
     return;
   }
 
@@ -972,7 +965,7 @@ void handle_edit_player_create(struct connection *pc, int tag)
   pplayer->unassigned_user = TRUE;
   pplayer->is_connected = FALSE;
   pplayer->government = init_government_of_nation(pnation);
-  pplayer->server.got_first_city = FALSE;
+  BV_CLR(pplayer->flags, PLRF_FIRST_CITY);
 
   pplayer->economic.gold = 0;
   pplayer->economic.infra_points = 0;
@@ -1133,6 +1126,26 @@ void handle_edit_player(struct connection *pc,
     }
   }
 
+  /* Handle a change in the player's infrapoints. */
+  if (packet->infrapoints != pplayer->economic.infra_points) {
+    if (!(0 <= packet->infrapoints && packet->infrapoints <= 1000000)) {
+      notify_conn(pc->self, NULL, E_BAD_COMMAND, ftc_editor,
+                  _("Cannot set infrapoints for player %d (%s) because "
+                    "the value %d is outside the allowed range."),
+                  player_number(pplayer), player_name(pplayer),
+                  packet->infrapoints);
+    } else {
+      pplayer->economic.infra_points = packet->infrapoints;
+      changed = TRUE;
+    }
+  }
+
+  /* Handle a change in the player's autoselect weight. */
+  if (packet->autoselect_weight != pplayer->autoselect_weight) {
+    pplayer->autoselect_weight = packet->autoselect_weight;
+    changed = TRUE;
+  }
+
   /* Handle player government change */
   gov = government_by_number(packet->government);
   if (gov != pplayer->government) {
@@ -1267,7 +1280,7 @@ void handle_edit_player_vision(struct connection *pc, int plr_no,
        * not give it vision. */
       unit_list_iterate(ptile->units, punit) {
         conn_list_iterate(pplayer->connections, pconn) {
-          dsend_packet_unit_remove(pconn, punit->id, punit->id);
+          dsend_packet_unit_remove(pconn, punit->id);
         } conn_list_iterate_end;
       } unit_list_iterate_end;
     }
@@ -1294,18 +1307,14 @@ void handle_edit_recalculate_borders(struct connection *pc)
 /************************************************************************//**
   Remove any city at the given location.
 ****************************************************************************/
-void handle_edit_city_remove(struct connection *pc, int id16, int id32)
+void handle_edit_city_remove(struct connection *pc, int id)
 {
   struct city *pcity;
 
-  if (!has_capability("ids32", pc->capability)) {
-    id32 = id16;
-  }
-
-  pcity = game_city_by_number(id32);
+  pcity = game_city_by_number(id);
   if (pcity == NULL) {
     notify_conn(pc->self, NULL, E_BAD_COMMAND, ftc_editor,
-                _("No such city (ID %d)."), id32);
+                _("No such city (ID %d)."), id);
     return;
   }
 
@@ -1345,12 +1354,12 @@ void handle_edit_toggle_fogofwar(struct connection *pc, int plr_no)
   }
 
   conn_list_do_buffer(game.est_connections);
-  if (unfogged_players[player_number(pplayer)]) {
+  if (unfogged_players[plr_no]) {
     enable_fog_of_war_player(pplayer);
-    unfogged_players[player_number(pplayer)] = FALSE;
+    unfogged_players[plr_no] = FALSE;
   } else {
     disable_fog_of_war_player(pplayer);
-    unfogged_players[player_number(pplayer)] = TRUE;
+    unfogged_players[plr_no] = TRUE;
   }
   conn_list_do_unbuffer(game.est_connections);
 }
@@ -1444,7 +1453,7 @@ void handle_edit_game(struct connection *pc,
     changed = TRUE;
   }
 
-  if (0 != strncmp(packet->scenario_name, game.scenario.name, 256)) {
+  if (fc_strncmp(packet->scenario_name, game.scenario.name, 256)) {
     sz_strlcpy(game.scenario.name, packet->scenario_name);
     changed = TRUE;
   }
@@ -1452,8 +1461,8 @@ void handle_edit_game(struct connection *pc,
   FC_STATIC_ASSERT(sizeof(packet->scenario_authors) == sizeof(game.scenario.authors),
                    scen_authors_field_size_mismatch);
 
-  if (0 != strncmp(packet->scenario_authors, game.scenario.authors,
-                   sizeof(game.scenario.authors))) {
+  if (fc_strncmp(packet->scenario_authors, game.scenario.authors,
+                 sizeof(game.scenario.authors))) {
     sz_strlcpy(game.scenario.authors, packet->scenario_authors);
     changed = TRUE;
   }
@@ -1499,8 +1508,8 @@ void handle_edit_game(struct connection *pc,
 ****************************************************************************/
 void handle_edit_scenario_desc(struct connection *pc, const char *scenario_desc)
 {
-  if (0 != strncmp(scenario_desc, game.scenario_desc.description,
-                   MAX_LEN_PACKET)) {
+  if (fc_strncmp(scenario_desc, game.scenario_desc.description,
+                 MAX_LEN_PACKET)) {
     sz_strlcpy(game.scenario_desc.description, scenario_desc);
     send_scenario_description(NULL);
   }
